@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents the options of saving dif file.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'DifSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -179,6 +179,41 @@ __PACKAGE__->method_documentation({
      	base_name => 'ValidateMergedAreas',
      	description => '',
      	format => '',
+     	read_only => '',
+     		},
+     'merge_areas' => {
+     	datatype => 'boolean',
+     	base_name => 'MergeAreas',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'sort_external_names' => {
+     	datatype => 'boolean',
+     	base_name => 'SortExternalNames',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'check_excel_restriction' => {
+     	datatype => 'boolean',
+     	base_name => 'CheckExcelRestriction',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'update_smart_art' => {
+     	datatype => 'boolean',
+     	base_name => 'UpdateSmartArt',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'encrypt_document_properties' => {
+     	datatype => 'boolean',
+     	base_name => 'EncryptDocumentProperties',
+     	description => '',
+     	format => '',
      	read_only => '',
      		},    
 });
@@ -191,7 +226,12 @@ __PACKAGE__->swagger_types( {
     'enable_http_compression' => 'boolean',
     'refresh_chart_cache' => 'boolean',
     'sort_names' => 'boolean',
-    'validate_merged_areas' => 'boolean' 
+    'validate_merged_areas' => 'boolean',
+    'merge_areas' => 'boolean',
+    'sort_external_names' => 'boolean',
+    'check_excel_restriction' => 'boolean',
+    'update_smart_art' => 'boolean',
+    'encrypt_document_properties' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -202,7 +242,12 @@ __PACKAGE__->attribute_map( {
     'enable_http_compression' => 'EnableHTTPCompression',
     'refresh_chart_cache' => 'RefreshChartCache',
     'sort_names' => 'SortNames',
-    'validate_merged_areas' => 'ValidateMergedAreas' 
+    'validate_merged_areas' => 'ValidateMergedAreas',
+    'merge_areas' => 'MergeAreas',
+    'sort_external_names' => 'SortExternalNames',
+    'check_excel_restriction' => 'CheckExcelRestriction',
+    'update_smart_art' => 'UpdateSmartArt',
+    'encrypt_document_properties' => 'EncryptDocumentProperties' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
