@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Class Summary: This class covers the features of artificial intelligence, machine learning, deep learning, and natural language processing.',
                                   class => 'ImportOption',
                                   required => [], # TODO
 }                                 );
@@ -136,7 +136,7 @@ __PACKAGE__->method_documentation({
      'is_insert' => {
      	datatype => 'boolean',
      	base_name => 'IsInsert',
-     	description => '',
+     	description => 'A boolean property `IsInsert` that can be both read and written.',
      	format => '',
      	read_only => '',
      		},
