@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the PageSections Response.',
                                   class => 'PageSectionsResponse',
                                   required => [], # TODO
 }                                 );
@@ -129,7 +129,7 @@ __PACKAGE__->method_documentation({
      'page_sections' => {
      	datatype => 'ARRAY[PageSection]',
      	base_name => 'PageSections',
-     	description => '',
+     	description => 'A property named PageSections of type List PageSection  to store a collection of PageSection objects.',
      	format => '',
      	read_only => '',
      		},
