@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -36,7 +36,8 @@ use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
 use AsposeCellsCloud::Object::Link;
-use AsposeCellsCloud::Object::LinkElement; 
+use AsposeCellsCloud::Object::LinkElement;
+use AsposeCellsCloud::Object::Series; 
 
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
@@ -119,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Class Summary:             - Features: Active class participation, group projects, quizzes, and final exam.',
                                   class => 'SeriesItems',
                                   required => [], # TODO
 }                                 );
@@ -129,7 +130,7 @@ __PACKAGE__->method_documentation({
      'category_data' => {
      	datatype => 'string',
      	base_name => 'CategoryData',
-     	description => '',
+     	description => 'This property allows setting and getting data for the category.',
      	format => '',
      	read_only => '',
      		},
@@ -148,7 +149,7 @@ __PACKAGE__->method_documentation({
      	read_only => '',
      		},
      'series_list' => {
-     	datatype => 'ARRAY[LinkElement]',
+     	datatype => 'ARRAY[Series]',
      	base_name => 'SeriesList',
      	description => '',
      	format => '',
@@ -167,7 +168,7 @@ __PACKAGE__->swagger_types( {
     'category_data' => 'string',
     'is_color_varied' => 'boolean',
     'second_catergory_data' => 'string',
-    'series_list' => 'ARRAY[LinkElement]',
+    'series_list' => 'ARRAY[Series]',
     'link' => 'Link' 
 } );
 
