@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -165,7 +165,7 @@ __PACKAGE__->method_documentation({
      'image' => {
      	datatype => 'LinkElement',
      	base_name => 'Image',
-     	description => '',
+     	description => 'The class has a public property named "Image" of type LinkElement that can be accessed and set.',
      	format => '',
      	read_only => '',
      		},    
