@@ -67,7 +67,7 @@ sub new {
 # ConvertChartToImageRequest.outPath : (Optional) The folder path where the workbook is stored. The default is null.  ,
 # ConvertChartToImageRequest.outStorageName : Output file Storage Name.  ,
 # ConvertChartToImageRequest.fontsLocation : Use Custom fonts.  ,
-# ConvertChartToImageRequest.regoin : The spreadsheet region setting.  ,
+# ConvertChartToImageRequest.region : The spreadsheet region setting.  ,
 # ConvertChartToImageRequest.password : The password for opening spreadsheet file.   
 
 {
@@ -129,8 +129,8 @@ sub run_http_request {
         $query_params->{'fontsLocation'} = $client->to_query_value($self->fonts_location);      
     }
 
-    if(defined $self->regoin){
-        $query_params->{'regoin'} = $client->to_query_value($self->regoin);      
+    if(defined $self->region){
+        $query_params->{'region'} = $client->to_query_value($self->region);      
     }
 
     if(defined $self->password){
@@ -139,7 +139,9 @@ sub run_http_request {
     my $_body_data;
 
 
-    $form_params->{basename($self->spreadsheet)} = [$self->spreadsheet ,basename($self->spreadsheet),'application/octet-stream'];
+    if (defined $self->spreadsheet) {   
+        $form_params->{basename($self->spreadsheet)} = [$self->spreadsheet ,basename($self->spreadsheet),'application/octet-stream'];
+    }
  
 
     # authentication setting, if any
@@ -201,9 +203,9 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
-     'regoin' => {
+     'region' => {
      	datatype => 'string',
-     	base_name => 'regoin',
+     	base_name => 'region',
      	description => 'The spreadsheet region setting.',
      	format => '',
      	read_only => '',
@@ -226,7 +228,7 @@ __PACKAGE__->attribute_map( {
     'out_path' => 'outPath',
     'out_storage_name' => 'outStorageName',
     'fonts_location' => 'fontsLocation',
-    'regoin' => 'regoin',
+    'region' => 'region',
     'password' => 'password' 
 } );
 
