@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -66,6 +67,8 @@ sub new {
 # GetWorksheetWithFormatRequest.horizontalResolution : Image horizontal resolution.  ,
 # GetWorksheetWithFormatRequest.area : Represents the range to be printed.  ,
 # GetWorksheetWithFormatRequest.pageIndex : Represents the page to be printed  ,
+# GetWorksheetWithFormatRequest.onePagePerSheet :   ,
+# GetWorksheetWithFormatRequest.printHeadings :   ,
 # GetWorksheetWithFormatRequest.folder : The folder where the file is situated.  ,
 # GetWorksheetWithFormatRequest.storageName : The storage name where the file is situated.   
 
@@ -90,7 +93,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/{name}/worksheets/{sheetName}';
+    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}';
 
     my $_method = 'GET';
     my $query_params = {};
@@ -134,6 +137,14 @@ sub run_http_request {
         $query_params->{'pageIndex'} = $client->to_query_value($self->page_index);      
     }
 
+    if(defined $self->one_page_per_sheet){
+        $query_params->{'onePagePerSheet'} = $client->to_query_value($self->one_page_per_sheet);      
+    }
+
+    if(defined $self->print_headings){
+        $query_params->{'printHeadings'} = $client->to_query_value($self->print_headings);      
+    }
+
     if(defined $self->folder){
         $query_params->{'folder'} = $client->to_query_value($self->folder);      
     }
@@ -142,6 +153,9 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
+
+ 
+
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -201,6 +215,20 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'one_page_per_sheet' => {
+     	datatype => 'string',
+     	base_name => 'onePagePerSheet',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'print_headings' => {
+     	datatype => 'string',
+     	base_name => 'printHeadings',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
@@ -226,6 +254,8 @@ __PACKAGE__->attribute_map( {
     'horizontal_resolution' => 'horizontalResolution',
     'area' => 'area',
     'page_index' => 'pageIndex',
+    'one_page_per_sheet' => 'onePagePerSheet',
+    'print_headings' => 'printHeadings',
     'folder' => 'folder',
     'storage_name' => 'storageName' 
 } );
