@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -87,7 +88,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/cells/columns/{columnIndex}/style';
+    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/cells/columns/{columnIndex}/style';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -126,11 +127,14 @@ sub run_http_request {
     } 
     my $_body_data;
 
+
     # body params
     if (defined $self->style) {
-        #$_body_data = $self->style;
          $_body_data = JSON->new->convert_blessed->encode( $self->style);
     }
+
+ 
+
     # authentication setting, if any
     my $auth_settings = [qw()];
 
