@@ -130,10 +130,7 @@ sub run_http_request {
 
 
     if (defined $self->file) {   
-        my $map_file = $self->file;
-        while ( my ($filename,$value) = each( %$map_file ) ) {
-                $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
-        }
+        $form_params->{basename($self->file)} = [$self->file ,basename($self->file),'application/octet-stream'];
     }
  
 
